@@ -43,7 +43,7 @@ where
                         return;
                     }
 
-                    if usage.used_in_loop {
+                    if usage.used_in_loop || usage.used_in_cond {
                         match &*assign.right {
                             Expr::Lit(..) | Expr::Ident(..) => {}
                             _ => return,
